/*
 * Copyright 2007-2008 The Kuali Foundation
 *
 * Licensed under the Educational Community License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.opensource.org/licenses/ecl2.php
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kuali.rice.kew.dto;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import org.kuali.rice.kew.util.KEWConstants;

/**
 * This is a virtual object representing the DocSearchCriteriaDTO class
 * 
 * @author Kuali Rice Team (rice.collab@kuali.org)
 */
public class DocumentSearchCriteriaDTO implements Serializable {

    private static final long serialVersionUID = -220572344702126103L;

    private String routeHeaderId; // id generated by KEW
    private String docRouteStatus; // route status of the document
    private String docTitle; // document title provided by the application
    private String appDocId; // application provided ID - defaults to routeHeaderId
    private String initiator; // network Id of the person who initiated the document
    private String viewer; // network Id of the person who is currently viewing the document
    private String groupViewerName; // group Id that has had an action request to the document
    private String approver; // network Id of the person who is approving the document
    private String docRouteNodeName; // current level of routing, i.e. which route method is the document currently in
    private String docRouteNodeLogic = KEWConstants.DOC_SEARCH_ROUTE_STATUS_QUALIFIER_EXACT; // exactly, before or after
    private String docVersion; // document version
    private String docTypeFullName; // the fullname for the document's docType

    // date range properties
    private String fromDateCreated; // the begin range for DateCreated
    private String fromDateLastModified; // the begin range for LastModified
    private String fromDateApproved; // the begin range for Approved
    private String fromDateFinalized; // the begin range for Finalized
    private String toDateCreated; // the end range for created
    private String toDateLastModified; // the end range for last modified
    private String toDateApproved; // the end range for approved
    private String toDateFinalized; // the end range for finalized

    // searchable attribute properties
    private List<KeyValueDTO> searchAttributeValues = new ArrayList<KeyValueDTO>();

    // below used only in specialized cases
    private boolean advancedSearch = false;
    private boolean superUserSearch = false;
    private Integer threshold = null;
    private Integer fetchLimit = null;
    private boolean saveSearchForUser = false;

    public void findDocsBeforeSpecifiedRouteNode() {
        setDocRouteNodeLogic(KEWConstants.DOC_SEARCH_ROUTE_STATUS_QUALIFIER_BEFORE);
    }

    public void findDocsAfterSpecifiedRouteNode() {
        setDocRouteNodeLogic(KEWConstants.DOC_SEARCH_ROUTE_STATUS_QUALIFIER_AFTER);
    }

    public void findDocsAtExactSpecifiedRouteNode() {
        setDocRouteNodeLogic(KEWConstants.DOC_SEARCH_ROUTE_STATUS_QUALIFIER_EXACT);
    }

    public String getRouteHeaderId() {
        return this.routeHeaderId;
    }

    public void setRouteHeaderId(String routeHeaderId) {
        this.routeHeaderId = routeHeaderId;
    }

    public String getDocRouteStatus() {
        return this.docRouteStatus;
    }

    public void setDocRouteStatus(String docRouteStatus) {
        this.docRouteStatus = docRouteStatus;
    }

    public String getDocTitle() {
        return this.docTitle;
    }

    public void setDocTitle(String docTitle) {
        this.docTitle = docTitle;
    }

    public String getAppDocId() {
        return this.appDocId;
    }

    public void setAppDocId(String appDocId) {
        this.appDocId = appDocId;
    }

    public String getInitiator() {
        return this.initiator;
    }

    public void setInitiator(String initiator) {
        this.initiator = initiator;
    }

    public String getViewer() {
        return this.viewer;
    }

    public void setViewer(String viewer) {
        this.viewer = viewer;
    }

    public String getGroupViewerName() {
        return this.groupViewerName;
    }

    public void setGroupViewerName(String groupViewerName) {
        this.groupViewerName = groupViewerName;
    }

    public String getApprover() {
        return this.approver;
    }

    public void setApprover(String approver) {
        this.approver = approver;
    }

    public String getDocRouteNodeName() {
        return this.docRouteNodeName;
    }

    public void setDocRouteNodeName(String docRouteNodeName) {
        this.docRouteNodeName = docRouteNodeName;
    }

    public String getDocRouteNodeLogic() {
        return this.docRouteNodeLogic;
    }

    public void setDocRouteNodeLogic(String docRouteNodeLogic) {
        this.docRouteNodeLogic = docRouteNodeLogic;
    }

    public String getDocVersion() {
        return this.docVersion;
    }

    public void setDocVersion(String docVersion) {
        this.docVersion = docVersion;
    }

    public String getDocTypeFullName() {
        return this.docTypeFullName;
    }

    public void setDocTypeFullName(String docTypeFullName) {
        this.docTypeFullName = docTypeFullName;
    }

    public String getFromDateCreated() {
        return this.fromDateCreated;
    }

    public void setFromDateCreated(String fromDateCreated) {
        this.fromDateCreated = fromDateCreated;
    }

    public String getFromDateLastModified() {
        return this.fromDateLastModified;
    }

    public void setFromDateLastModified(String fromDateLastModified) {
        this.fromDateLastModified = fromDateLastModified;
    }

    public String getFromDateApproved() {
        return this.fromDateApproved;
    }

    public void setFromDateApproved(String fromDateApproved) {
        this.fromDateApproved = fromDateApproved;
    }

    public String getFromDateFinalized() {
        return this.fromDateFinalized;
    }

    public void setFromDateFinalized(String fromDateFinalized) {
        this.fromDateFinalized = fromDateFinalized;
    }

    public String getToDateCreated() {
        return this.toDateCreated;
    }

    public void setToDateCreated(String toDateCreated) {
        this.toDateCreated = toDateCreated;
    }

    public String getToDateLastModified() {
        return this.toDateLastModified;
    }

    public void setToDateLastModified(String toDateLastModified) {
        this.toDateLastModified = toDateLastModified;
    }

    public String getToDateApproved() {
        return this.toDateApproved;
    }

    public void setToDateApproved(String toDateApproved) {
        this.toDateApproved = toDateApproved;
    }

    public String getToDateFinalized() {
        return this.toDateFinalized;
    }

    public void setToDateFinalized(String toDateFinalized) {
        this.toDateFinalized = toDateFinalized;
    }

    public List<KeyValueDTO> getSearchAttributeValues() {
        return this.searchAttributeValues;
    }

    public void setSearchAttributeValues(List<KeyValueDTO> searchAttributeValues) {
        this.searchAttributeValues = searchAttributeValues;
    }

    public boolean isAdvancedSearch() {
        return this.advancedSearch;
    }

    public void setAdvancedSearch(boolean advancedSearch) {
        this.advancedSearch = advancedSearch;
    }

    public boolean isSuperUserSearch() {
        return this.superUserSearch;
    }

    public void setSuperUserSearch(boolean superUserSearch) {
        this.superUserSearch = superUserSearch;
    }

    public Integer getThreshold() {
        return this.threshold;
    }

    public void setThreshold(Integer threshold) {
        this.threshold = threshold;
    }

	public boolean isSaveSearchForUser() {
		return this.saveSearchForUser;
	}

	public void setSaveSearchForUser(boolean saveSearchForUser) {
		this.saveSearchForUser = saveSearchForUser;
	}

}
